@@ -1,23 +1,11 @@
 /*
- * Copyright (C) 2015-2020 VMware, Inc. All Rights Reserved.
+ * Copyright (C) 2015-2022 VMware, Inc. All Rights Reserved.
  *
  * Licensed under the GNU Lesser General Public License v2.1 (the "License");
  * you may not use this file except in compliance with the License. The terms
  * of the License are located in the COPYING file of this distribution.
  */
 
-/*
- * Header : includes.h
- *
- * Abstract :
- *
- *            tdnfclientlib
- *
- *            client library
- *
- * Authors  : Priyesh Padmavilasom (ppadmavilasom@vmware.com)
- */
-
 #ifndef __CLIENT_INCLUDES_H__
 #define __CLIENT_INCLUDES_H__
 
@@ -37,6 +25,7 @@
 #include <libgen.h>
 #include <ctype.h>
 #include <sys/file.h>
+#include <time.h>
 #include <sys/utsname.h>
 
 #include <dirent.h>
